% Copyright (c) 2011 Department of Information Engineering, University of Padova, Italy
% Contributors: Davide Zordan, 7 Mar. 2011
% All rights reserved

% Redistribution and use in source and binary forms, with or without
% modification, are permitted provided that the following conditions are
% met:
%
%    * Redistributions of source code must retain the above copyright
%      notice, this list of conditions and the following disclaimer.
%    * Redistributions in binary form must reproduce the above
%      copyright notice, this list of conditions and the following
%      disclaimer in the documentation and/or other materials provided
%      with the distribution.
%    * The name of the author may not be used to endorse or promote
%      products derived from this software without specific prior
%      written permission.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
% "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
% LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
% A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
% OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
% SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
% LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
% DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
% THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
% (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
% OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


function [f1,fe1,f2,fe2] = createFit(x,y)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%CREATEFIT Create fits of the dataset 
%   CREATEFIT(X,Y)
%   Creates two fits, using power exponential model and rational quadratic 
%   model. Returns the parameters of the two fits and the error statistics. 
%
%   Number of data sets:  1
%   Number of fits:  2

% Data from data set "y vs. x":
%     X = x:
%     Y = y:
%     Unweighted
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

xlim_ = [Inf -Inf];

x = x(:);
y = y(:);

xlim_(1) = min(xlim_(1),min(x));
xlim_(2) = max(xlim_(2),max(x));


% --- Create fit "fit 1"
fo_ = fitoptions('method','NonlinearLeastSquares','Lower',[0    0],'Upper',[Inf      2]);
ok_ = isfinite(x) & isfinite(y);
if ~all( ok_ )
    warning( 'GenerateMFile:IgnoringNansAndInfs',...
        'Ignoring NaNs and Infs in data.' );
end
st_ = [0.42999287773226613218 0.53912198976730651978 ];
set(fo_,'Startpoint',st_);
ft_ = fittype('exp(-(x./b).^c)',...
    'dependent',{'y'},'independent',{'x'},...
    'coefficients',{'b', 'c'});

% Fit this model using new data
[cf_ , ferr_1]= fit(x(ok_),y(ok_),ft_,fo_);


f1=cf_;
fe1=ferr_1;

% --- Create fit "fit 2"
fo_ = fitoptions('method','NonlinearLeastSquares','Lower',[0    0],'Upper',[Inf      2]);
ok_ = isfinite(x) & isfinite(y);
if ~all( ok_ )
    warning( 'GenerateMFile:IgnoringNansAndInfs',...
        'Ignoring NaNs and Infs in data.' );
end
st_ = [0.42999287773226613218 0.53912198976730651978 ];
set(fo_,'Startpoint',st_);
ft_ = fittype('1./(1+(20^(1/c)-1).*(x./b).^2).^c',...
    'dependent',{'y'},'independent',{'x'},...
    'coefficients',{'b', 'c'});

% Fit this model using new data
[cf_ , ferr_2] = fit(x(ok_),y(ok_),ft_,fo_);


f2 = cf_;
fe2 = ferr_2;

end
