% Copyright (c) 2011 Department of Information Engineering, University of Padova, Italy
% Contributors: Davide Zordan, 7 Mar. 2011
% All rights reserved

% Redistribution and use in source and binary forms, with or without
% modification, are permitted provided that the following conditions are
% met:
%
%    * Redistributions of source code must retain the above copyright
%      notice, this list of conditions and the following disclaimer.
%    * Redistributions in binary form must reproduce the above
%      copyright notice, this list of conditions and the following
%      disclaimer in the documentation and/or other materials provided
%      with the distribution.
%    * The name of the author may not be used to endorse or promote
%      products derived from this software without specific prior
%      written permission.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
% "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
% LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
% A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
% OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
% SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
% LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
% DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
% THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
% (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
% OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


load dataset/dei_lum/data.mat

%[xr,yr] = spatial_correlation_lat_long(data, 20, 50000);
[xr,yr] = spatial_correlation_xy(data, 20 , 50000);

r = real_data_one_step_temporal_correlation(data);

[f1p,fe1p,f2p,fe2p] = createFit(xr,yr);


dim_grid = 1000;
x = -(ceil(dim_grid/2) - 1):1:floor(dim_grid/2);
y = -(ceil(dim_grid/2) - 1):1:floor(dim_grid/2);

[X,Y] = meshgrid(x,y);

% selection of the best fitting
% creation of the correlation matrix C
if (fe1p.rmse < fe2p.rmse)
    model = 1; 
    disp('power exp');
    xi_f = fe1p.rmse;
    zeta = f1p.b * sqrt(2*(99)^2);
    nu = f1p.c;
    C = (exp(-(sqrt(X.^2 + Y.^2)./zeta).^nu));
else
    model = 2;
    disp('rational quadratic');
    xi_f = fe2p.rmse;
    zeta = f2p.b * sqrt(2*(99)^2);
    nu = f2p.c;
    C = 1./(1+(20.^(1/nu)-1).*(sqrt(X.^2 + Y.^2)./zeta).^2).^nu;
end

[synt_data, xc, yc,RoT] = generate_synthetic_signal(1000,10,C,r);

if (model==1)
    xi_s = sqrt(sum(((yc' - f1p(xc)).^2)./length(xc)));
else
    xi_s = sqrt(sum(((yc' - f2p(xc)).^2)./length(xc)));
end

deltaRoT = abs(r - RoT)./r;

plot_figure(1,xr,yr,f1p,f2p,xc,yc,0);
