% Copyright (c) 2011 Department of Information Engineering, University of Padova, Italy
% Contributors: Davide Zordan, 7 Mar. 2011
% All rights reserved

% Redistribution and use in source and binary forms, with or without
% modification, are permitted provided that the following conditions are
% met:
%
%    * Redistributions of source code must retain the above copyright
%      notice, this list of conditions and the following disclaimer.
%    * Redistributions in binary form must reproduce the above
%      copyright notice, this list of conditions and the following
%      disclaimer in the documentation and/or other materials provided
%      with the distribution.
%    * The name of the author may not be used to endorse or promote
%      products derived from this software without specific prior
%      written permission.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
% "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
% LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
% A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
% OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
% SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
% LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
% DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
% THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
% (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
% OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

function plot_figure(num,xr,yr,f1p,f2p,xc,yc,onfile)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PLOT_FIGURE plot a figure with real data spatial correlation, the two
%  models used for the fitting and the spatial correlation of the synthetic
%  signal generated.
% 
% Inputs: 
%   num             number of the figure
%   xr, yr          real data spatial correlation points to be plotted
%   f1p,f2p         parameters of the two fits
%   xc, yc          synthetic data spatial correlation points to be plotted
%   onfile          if 1 save the figure on a file named g#.eps
%                    (where # = num) 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(num);

legh_ = [];
legt_ = {};
ax_ = axes;
set(ax_,'Units','normalized','OuterPosition',[0 0 1 1]);
set(ax_,'Box','on');
axes(ax_);
hold on;

line(xr,yr,'Parent',ax_,'Color',[0 0 0],...
    'LineStyle','none', 'LineWidth',2,...
    'Marker','o', 'MarkerSize',10);

h_ = line(xr(1),yr(1),'Parent',ax_,'Color',[0 0 0],...
    'LineStyle',':', 'LineWidth',2,...
    'Marker','o', 'MarkerSize',10);

legh_(end+1) = h_;
legt_{end+1} = 'Real data';


h_ = plot(f1p,'fit',0.95);
set(h_(1),'Color',[0 0 0],...
    'LineStyle','-', 'LineWidth',2,...
    'Marker','none', 'MarkerSize',6);

legend off;

legh_(end+1) = h_(1);
legt_{end+1} = 'Exponential model';

h_ = plot(f2p,'fit',0.95);
set(h_(1),'Color',[0 0 0],...
    'LineStyle','--', 'LineWidth',2,...
    'Marker','none', 'MarkerSize',6);
% Turn off legend created by plot method.
legend off;
% Store line handle and fit name for legend.
legh_(end+1) = h_(1);
legt_{end+1} = 'Rational quadratic model';

plot(xc,yc,'ks','MarkerSize',10,'LineWidth',2);
h_ = plot(xc(1),yc(1),'ks:','MarkerSize',10,'LineWidth',2);
legh_(end+1) = h_(1);
legt_{end+1} = 'Synthetic Data';
plot(xc,yc,'k:','LineWidth',1.2);
plot(xr,yr,'k:','LineWidth',1.2);

axis([0 1 0 1.1]);
set(gca,'Fontsize',20);
grid;
xlabel(ax_,'$d/d_M$','Interpreter','latex','fontsize',24);
ylabel(ax_,'$\rho_S$','Interpreter','latex','fontsize',24);
set(gca,'XTick',0:.2:1);
set(gca,'XTickLabel',{'','0.2','0.4','0.6','0.8', '1'});


hold off;
% Display legend
leginfo_ = {'Orientation', 'vertical', 'Location', 'NorthEast'};
h_ = legend(ax_,legh_,legt_,leginfo_{:});
set(h_,'Interpreter','latex');

if (onfile==1)
    saveas(num,['g' num2str(num) '.eps'],'epsc');
end

end
