% Copyright (c) 2011 Department of Information Engineering, University of Padova, Italy
% Contributors: Davide Zordan, 7 Mar. 2011
% All rights reserved

% Redistribution and use in source and binary forms, with or without
% modification, are permitted provided that the following conditions are
% met:
%
%    * Redistributions of source code must retain the above copyright
%      notice, this list of conditions and the following disclaimer.
%    * Redistributions in binary form must reproduce the above
%      copyright notice, this list of conditions and the following
%      disclaimer in the documentation and/or other materials provided
%      with the distribution.
%    * The name of the author may not be used to endorse or promote
%      products derived from this software without specific prior
%      written permission.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
% "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
% LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
% A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
% OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
% SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
% LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
% DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
% THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
% (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
% OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

function [x, y] = spatial_correlation_lat_long(data_in, n_lags, n_samples)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%SPATIAL_CORRELATION_LAT_LONG Calculate the spatial correlation of a real
%       signal, where the positions are given in latitude and longitude
%
% Inputs:
%   data_in[N,T+2]      readings from N sensors for T time instants
%                       the first 2 columns give the position of the sensor
%                       (long, lat in decimal degrees)
%   n_lags              number of points for the representation of rho_S  
%   n_samples           number of couples to be considered  
%
% Outputs:
%   x                   distance intervals
%   y                   spatial correlation 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

RoS = [];
D = [];
if (n_lags < 4)
    n_lags = 20;
end
N = size(data_in,1);
T = size(data_in,2);

for n=1:n_samples
        % find correlation between ni and nj
        i = floor(rand*N)+1;
        j = floor(rand*N)+1;
        X = data_in(i,3:T);
        Y = data_in(j,3:T);
        rs = mean((X - mean(X)).*(Y - mean(Y))./(std(X)*std(Y)));
        
        d = distance(data_in(i,2),data_in(i,1),data_in(j,2),data_in(j,1),[6360 0]);
        if ~isnan(rs)
            RoS = [RoS rs];
            D = [D d];
        end
end

step = max(D)./n_lags;
RoS2 = [1];
D2 = [0];
for i=1:n_lags
    index = (D > (i-1)*step) & (D <= (i)*step);
    RoS2 = [RoS2 mean(RoS(index))];
    D2 = [D2 i*step];
end

RoS2(RoS2 < 0) = 0;
x = D2./max(D2);
y = RoS2;

end
