% Copyright (c) 2011 Department of Information Engineering, University of Padova, Italy
% Contributors: Davide Zordan, 7 Mar. 2011
% All rights reserved

% Redistribution and use in source and binary forms, with or without
% modification, are permitted provided that the following conditions are
% met:
%
%    * Redistributions of source code must retain the above copyright
%      notice, this list of conditions and the following disclaimer.
%    * Redistributions in binary form must reproduce the above
%      copyright notice, this list of conditions and the following
%      disclaimer in the documentation and/or other materials provided
%      with the distribution.
%    * The name of the author may not be used to endorse or promote
%      products derived from this software without specific prior
%      written permission.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
% "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
% LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
% A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
% OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
% SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
% LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
% DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
% THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
% (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
% OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

function [ RoT_1 ] = synt_data_one_step_temporal_correlation(Z)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%SYNT_DATA_ONE_STEP_TEMPORAL_CORRELATION
% Calculate the average one step temporal correlation coefficient of the 
% synthetic signal
%
% Inputs:
%   Z [NxMxT]   synthetic signal on a NxM grid for T time instants 
%                       
% Outputs:
%   RoT_1       one step temporal correlation
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

T = size(Z,3);
N = size(Z,1);
M = size(Z,2);

R = zeros(1, T-1);

for t = 1:T-1
    
    R(t) = mean(mean((Z(:,:,t)-mean(mean(Z(:,:,t)))).*(Z(:,:,t+1)-mean(mean...
        (Z(:,:,t+1))))))./(std(reshape(Z(:,:,t),1,N*M)*std(reshape(Z(:,:,t+1),1,N*M))));
    
end
RoT_1 = mean(R);
end

