% Copyright (c) 2011 Department of Information Engineering, University of Padova, Italy
% Contributors: Davide Zordan, 7 Mar. 2011
% All rights reserved

% Redistribution and use in source and binary forms, with or without
% modification, are permitted provided that the following conditions are
% met:
%
%    * Redistributions of source code must retain the above copyright
%      notice, this list of conditions and the following disclaimer.
%    * Redistributions in binary form must reproduce the above
%      copyright notice, this list of conditions and the following
%      disclaimer in the documentation and/or other materials provided
%      with the distribution.
%    * The name of the author may not be used to endorse or promote
%      products derived from this software without specific prior
%      written permission.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
% "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
% LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
% A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
% OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
% SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
% LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
% DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
% THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
% (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
% OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

function [ x, y ] = synt_data_spatial_correlation(Z, n_lags, n_samples)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SYNT_DATA_SPATIAL_CORRELATION
% Calculate the spatial correlation of the synthetic data
%
% Inputs:
%   Z                 synthetic data  
%   n_lags            number of points for the representation of rho_S  
%   n_samples         number of couples to be considered 
%
% Outputs:
%   x                   distance intervals
%   y                   spatial correlation 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
N = size(Z,1);
RoS = [];
D = [];

% mean and variance of the field
mu = mean2(Z);
sig = (std2(Z)).^2;

for in=1:n_samples
    i = floor(rand*N)+1;
    j = floor(rand*N)+1;
    k = floor(rand*N)+1;
    l = floor(rand*N)+1;
   
    X = Z(i,j);
    Y = Z(k,l);
    rs = (X - mu)*(Y - mu)/sig;

    d = sqrt((i-k)^2 + (j-l)^2);
    if ~isnan(rs)
        RoS = [RoS rs];
        D = [D d];
    end
end

step = sqrt(2*99^2)/n_lags;
RoS2 = [1];
D2 = [0];
for i=1:n_lags
    index = (D > (i-1)*step) & (D <= (i)*step);
    RoS2 = [RoS2 mean(RoS(index))];
    D2 = [D2 i*step];
end

RoS2(RoS2 < 0) = 0;

x = D2;
y = RoS2;
end
